package com.datacloudsec.utils;

import com.datacloudsec.exception.UEException;
import java.io.File;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;
import net.lingala.zip4j.core.ZipFile;
import net.lingala.zip4j.model.ZipParameters;
import org.apache.commons.lang.StringUtils;

public class ZipUtil {

   public static File unZip(File zipFile, File unzipDir, String password) throws Exception {
      ZipFile zip = new ZipFile(zipFile);
      zip.setFileNameCharset("UTF-8");
      if(!zip.isValidZipFile()) {
         throw new UEException("压缩文件不合法,可能被损坏.");
      } else {
         if(zip.isEncrypted()) {
            if(StringUtils.isBlank(password)) {
               throw new UEException("密码错误.");
            }

            zip.setPassword(password);
         }

         String zipName = zipFile.getName();
         if(zipName.contains(".")) {
            zipName = zipName.substring(0, zipName.lastIndexOf("."));
         }

         if(unzipDir == null) {
            unzipDir = new File(zipFile.getParent(), zipName);
         }

         for(int e = 1; unzipDir.exists() && !unzipDir.isDirectory(); ++e) {
            unzipDir = new File(unzipDir.getAbsolutePath() + "_" + e);
            if(!unzipDir.exists()) {
               unzipDir.mkdirs();
            }
         }

         try {
            zip.extractAll(unzipDir.getAbsolutePath());
            return unzipDir;
         } catch (Exception var6) {
            Object var7 = var6;
            if(var6.getMessage().toLowerCase().contains("password")) {
               var7 = new UEException("密码错误！");
            }

            throw (Exception)var7;
         }
      }
   }

   public static File unZip(File zipFile, String name, File unzipDir, String password) throws Exception {
      ZipFile zip = new ZipFile(zipFile);
      zip.setFileNameCharset("UTF-8");
      if(!zip.isValidZipFile()) {
         throw new UEException("压缩文件不合法,可能被损坏.");
      } else {
         if(zip.isEncrypted()) {
            if(StringUtils.isBlank(password)) {
               throw new UEException("密码错误.");
            }

            zip.setPassword(password);
         }

         if(unzipDir == null) {
            unzipDir = zipFile.getParentFile();
         }

         try {
            zip.extractFile(name, unzipDir.getAbsolutePath());
         } catch (Exception var6) {
            Object e = var6;
            if(var6.getMessage().toLowerCase().contains("password")) {
               e = new UEException("密码错误！");
            }

            throw (Exception)e;
         }

         return new File(unzipDir, name);
      }
   }

   public static void toZip(File destFile, File[] srcFiles, String password) throws Exception {
      ZipParameters parameters = new ZipParameters();
      parameters.setCompressionMethod(8);
      parameters.setCompressionLevel(5);
      if(StringUtils.isNotEmpty(password)) {
         parameters.setEncryptFiles(true);
         parameters.setEncryptionMethod(99);
         parameters.setAesKeyStrength(3);
         parameters.setPassword(password);
      }

      File destDir = destFile.getParentFile();
      if(!destDir.isDirectory()) {
         destDir.mkdirs();
      }

      ZipFile zipFile = new ZipFile(destFile);
      File[] var9 = srcFiles;
      int var8 = srcFiles.length;

      for(int var7 = 0; var7 < var8; ++var7) {
         File file = var9[var7];
         if(file.isFile()) {
            zipFile.addFile(file, parameters);
         } else {
            zipFile.addFolder(file, parameters);
         }
      }

   }

   public static void toZip(File destFile, File[] srcFiles, String[] newNames, String password) throws Exception {
      if(destFile.isFile()) {
         destFile.delete();
      }

      ZipParameters parameters = new ZipParameters();
      parameters.setCompressionMethod(8);
      parameters.setCompressionLevel(5);
      parameters.setSourceExternalStream(true);
      if(StringUtils.isNotEmpty(password)) {
         parameters.setEncryptFiles(true);
         parameters.setEncryptionMethod(99);
         parameters.setAesKeyStrength(3);
         parameters.setPassword(password);
      }

      File destDir = destFile.getParentFile();
      if(!destDir.isDirectory()) {
         destDir.mkdirs();
      }

      ZipFile zipFile = new ZipFile(destFile);

      for(int i = 0; i < srcFiles.length; ++i) {
         File file = srcFiles[i];
         String zipInName;
         if(newNames != null && i < newNames.length && StringUtils.isNotBlank(newNames[i])) {
            zipInName = newNames[i];
            zipInName = zipInName.replaceAll("\\\\|/|:|\\*|\\?|<|>|\"|\\|", "");
         } else {
            zipInName = file.getName();
         }

         if(file.isFile()) {
            parameters.setFileNameInZip(zipInName);
            zipFile.addFile(file, parameters);
         } else if(file.isDirectory()) {
            Map files = findFile(file, zipInName + "/");
            Iterator var12 = files.entrySet().iterator();

            while(var12.hasNext()) {
               Entry entry = (Entry)var12.next();
               parameters.setFileNameInZip((String)entry.getValue());
               zipFile.addFile((File)entry.getKey(), parameters);
            }
         }
      }

   }

   public static void appendFile(File zFile, File file, String password) throws Exception {
      ZipFile zipFile = new ZipFile(zFile);
      if(zipFile.isEncrypted()) {
         if(password == null) {
            throw new UEException("密码错误.");
         }

         zipFile.setPassword(password);
      }

      ZipParameters parameters = new ZipParameters();
      parameters.setCompressionMethod(8);
      parameters.setCompressionLevel(5);
      zipFile.addFile(file, parameters);
   }

   private static Map findFile(File dir, String path) {
      if(StringUtils.isBlank(path)) {
         path = dir.getName() + "/";
      }

      HashMap m = new HashMap();
      if(dir.isDirectory()) {
         File[] files = dir.listFiles();
         if(files != null) {
            File[] var7 = files;
            int var6 = files.length;

            for(int var5 = 0; var5 < var6; ++var5) {
               File f = var7[var5];
               if(f.isFile()) {
                  m.put(f, path + f.getName());
               } else {
                  m.putAll(findFile(f, path + f.getName() + "/"));
               }
            }
         }
      }

      return m;
   }

   public static void main(String[] args) throws Exception {
      File[] srcFiles = new File[]{new File("D:/桌面/klge.js"), new File("D:/桌面/klge.sql"), new File("D:/work/ui/值班系统/ICON")};
      String[] newNames = new String[]{"k.js", "k.sql", "ico"};
      toZip(new File("d:/a.zip"), srcFiles, newNames, (String)null);
   }
}
